import React, { useState, useCallback } from 'react'
import { loginSchema, LoginFormData, FieldErrors } from '../validation'
import { ZodError } from 'zod'

interface UseLoginFormProps {
    onSubmitSuccess?: (data: LoginFormData) => void // Optional callback for successful submission
}

export function useLoginForm({ onSubmitSuccess }: UseLoginFormProps = {}) {
    const [formData, setFormData] = useState<LoginFormData>({
        identifier: '', // Can hold email or username
        password: '',
        saveLogin: false,
        savePassword: false,
    })
    const [errors, setErrors] = useState<FieldErrors<LoginFormData>>({})
    const [isLoading, setIsLoading] = useState(false)
    const [submitError, setSubmitError] = useState<string | null>(null)

    const handleChange = useCallback(
        (e: React.ChangeEvent<HTMLInputElement>) => {
            const { name, value, type, checked } = e.target
            setFormData(prev => ({
                ...prev,
                [name]: type === 'checkbox' ? checked : value,
            }))
            // Clear error for the field being edited
            if (errors[name as keyof LoginFormData]) {
                setErrors(prev => ({ ...prev, [name]: undefined }))
            }
            // Clear general submission error
            if (submitError) {
                setSubmitError(null)
            }
        },
        [errors, submitError],
    )

    const validateForm = useCallback(() => {
        try {
            loginSchema.parse(formData)
            setErrors({})
            return true
        } catch (error) {
            if (error instanceof ZodError) {
                const fieldErrors: FieldErrors<LoginFormData> = {}
                error.errors.forEach(err => {
                    if (err.path.length > 0) {
                        fieldErrors[err.path[0] as keyof LoginFormData] =
                            err.message
                    }
                })
                setErrors(fieldErrors)
            } else {
                console.error(
                    'An unexpected error occurred during validation:',
                    error,
                )
                setSubmitError('An unexpected validation error occurred.')
            }
            return false
        }
    }, [formData])

    const handleSubmit = useCallback(
        async (e: React.FormEvent<HTMLFormElement>) => {
            e.preventDefault()
            setSubmitError(null)

            if (!validateForm()) {
                return
            }

            setIsLoading(true)
            console.log('Submitting login data:', formData)

            try {
                setErrors({}) // Clear errors on success
                if (onSubmitSuccess) {
                    onSubmitSuccess(formData) // Call success callback
                }
            } catch (apiError: unknown) {
                console.error('Login API error:', apiError)
                setSubmitError('Login failed. Please check your credentials.')
            } finally {
                setIsLoading(false)
            }
        },
        [formData, validateForm, onSubmitSuccess],
    )

    return {
        formData,
        errors,
        isLoading,
        submitError,
        handleChange,
        handleSubmit,
    }
}
